======================
Contribute to Espresso
======================

Thank you for contributing to Espresso! Espresso is a community driven effort to 
create a collection of forward codes, simulating a wide range of physical problems.

.. rubric:: New forward example

Espresso relies on you to contribute your forward code! You do not need to know all 
the details to get started. If you are considering contributing with a new forward 
problem, welcome 🥰! Please head to `this page <new_contrib.html>`_ for detailed 
instructions.

.. rubric:: Issue report and feedback

If you'd like to raise an issue or feedback, please search before lodging an issue at
our Github `repository`_. 

We also welcome you to join our inlab-community `Slack`_.

.. rubric:: Developing Espresso

If you'd like to fix a bug or add a feature to Espresso utilities via coding,
please check out our `developer notes <../developer_notes/develop.html>`_ for 
full instructions.
